Downloads precompiled NIF artifacts and generates a checksum file.
This task is for package maintainers who want to ship precompiled Zig NIFs. It downloads precompiled packages and generates a checksum file to include in the Hex package.
Usage
mix zigler_precompiled.download MyApp.MyNative --all --printFlags
--all— Download all platform artifacts--only-local— Download only the artifact for the current platform--print— Print checksums to stdout (default: true)--ignore-unavailable— Skip unavailable platform artifacts--no-config— Skipapp.configstep